﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Windows.Forms;
using HeuristicLab.Common.Resources;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.Problems.QuadraticAssignment.Views {
  [View("Quadratic Assignment Problem View")]
  [Content(typeof(QuadraticAssignmentProblem), IsDefaultView = true)]
  public sealed partial class QuadraticAssignmentProblemView : ParameterizedNamedItemView {
    public new QuadraticAssignmentProblem Content {
      get { return (QuadraticAssignmentProblem)base.Content; }
      set { base.Content = value; }
    }

    public QuadraticAssignmentProblemView() {
      InitializeComponent();
      importInstanceButton.Image = VSImageLibrary.Open;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      instancesComboBox.Items.Clear();
      if (Content != null) {
        foreach (string instance in Content.EmbeddedInstances) {
          instancesComboBox.Items.Add(instance);
        }
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      instancesComboBox.Enabled = !ReadOnly && !Locked && Content != null;
      loadInstanceButton.Enabled = !ReadOnly && !Locked && Content != null && instancesComboBox.SelectedItem != null;
      importInstanceButton.Enabled = !ReadOnly && !Locked && Content != null;
    }

    private void instancesComboBox_SelectedValueChanged(object sender, System.EventArgs e) {
      loadInstanceButton.Enabled = instancesComboBox.SelectedItem != null;
    }

    private void loadInstanceButton_Click(object sender, System.EventArgs e) {
      string instance = instancesComboBox.SelectedItem as string;
      Content.LoadEmbeddedInstance(instance);
    }

    private void importInstanceButton_Click(object sender, System.EventArgs e) {
      if (openFileDialog.ShowDialog() == DialogResult.OK) {
        Content.ImportFileInstance(openFileDialog.FileName);
      }
    }
  }
}
